# tester-sdk
Giphy API

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.0
- Package version: 1.0.0
- Generator version: 7.11.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python 3.8+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import tester_sdk
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import tester_sdk
```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import tester_sdk
from tester_sdk.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://api.giphy.com/v1
# See configuration.py for a list of all supported configuration parameters.
configuration = tester_sdk.Configuration(
    host = "https://api.giphy.com/v1"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: api_key
configuration.api_key['api_key'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['api_key'] = 'Bearer'


# Enter a context with an instance of the API client
with tester_sdk.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = tester_sdk.GifsApi(api_client)
    gif_id = 56 # int | Filters results by specified GIF ID.

    try:
        # Get GIF by Id
        api_response = api_instance.get_gif_by_id(gif_id)
        print("The response of GifsApi->get_gif_by_id:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling GifsApi->get_gif_by_id: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *https://api.giphy.com/v1*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*GifsApi* | [**get_gif_by_id**](docs/GifsApi.md#get_gif_by_id) | **GET** /gifs/{gifId} | Get GIF by Id
*GifsApi* | [**get_gifs_by_id**](docs/GifsApi.md#get_gifs_by_id) | **GET** /gifs | Get GIFs by ID
*GifsApi* | [**random_gif**](docs/GifsApi.md#random_gif) | **GET** /gifs/random | Random GIF
*GifsApi* | [**search_gifs**](docs/GifsApi.md#search_gifs) | **GET** /gifs/search | Search GIFs
*GifsApi* | [**translate_gif**](docs/GifsApi.md#translate_gif) | **GET** /gifs/translate | Translate phrase to GIF
*GifsApi* | [**trending_gifs**](docs/GifsApi.md#trending_gifs) | **GET** /gifs/trending | Trending GIFs
*StickersApi* | [**random_sticker**](docs/StickersApi.md#random_sticker) | **GET** /stickers/random | Random Sticker
*StickersApi* | [**search_stickers**](docs/StickersApi.md#search_stickers) | **GET** /stickers/search | Search Stickers
*StickersApi* | [**translate_sticker**](docs/StickersApi.md#translate_sticker) | **GET** /stickers/translate | Translate phrase to Sticker
*StickersApi* | [**trending_stickers**](docs/StickersApi.md#trending_stickers) | **GET** /stickers/trending | Trending Stickers


## Documentation For Models

 - [GetGifsById200Response](docs/GetGifsById200Response.md)
 - [Gif](docs/Gif.md)
 - [GifImages](docs/GifImages.md)
 - [GifImagesDownsized](docs/GifImagesDownsized.md)
 - [GifImagesDownsizedLarge](docs/GifImagesDownsizedLarge.md)
 - [GifImagesDownsizedMedium](docs/GifImagesDownsizedMedium.md)
 - [GifImagesDownsizedSmall](docs/GifImagesDownsizedSmall.md)
 - [GifImagesDownsizedStill](docs/GifImagesDownsizedStill.md)
 - [GifImagesFixedHeight](docs/GifImagesFixedHeight.md)
 - [GifImagesFixedHeightDownsampled](docs/GifImagesFixedHeightDownsampled.md)
 - [GifImagesFixedHeightSmall](docs/GifImagesFixedHeightSmall.md)
 - [GifImagesFixedHeightSmallStill](docs/GifImagesFixedHeightSmallStill.md)
 - [GifImagesFixedHeightStill](docs/GifImagesFixedHeightStill.md)
 - [GifImagesFixedWidth](docs/GifImagesFixedWidth.md)
 - [GifImagesFixedWidthDownsampled](docs/GifImagesFixedWidthDownsampled.md)
 - [GifImagesFixedWidthSmall](docs/GifImagesFixedWidthSmall.md)
 - [GifImagesFixedWidthSmallStill](docs/GifImagesFixedWidthSmallStill.md)
 - [GifImagesFixedWidthStill](docs/GifImagesFixedWidthStill.md)
 - [GifImagesLooping](docs/GifImagesLooping.md)
 - [GifImagesOriginal](docs/GifImagesOriginal.md)
 - [GifImagesOriginalStill](docs/GifImagesOriginalStill.md)
 - [GifImagesPreview](docs/GifImagesPreview.md)
 - [GifImagesPreviewGif](docs/GifImagesPreviewGif.md)
 - [Image](docs/Image.md)
 - [Meta](docs/Meta.md)
 - [Pagination](docs/Pagination.md)
 - [RandomGif200Response](docs/RandomGif200Response.md)
 - [User](docs/User.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization


Authentication schemes defined for the API:
<a id="api_key"></a>
### api_key

- **Type**: API key
- **API key parameter name**: api_key
- **Location**: URL query string


## Author

support@giphy.com


